# mediaApiClient
It is an opensource library for working with api ContentApiGate, written in python.

## Installation

Install the current version with [PyPI](https://pypi.org/):

```bash
pip install mediaApiClient
```

## Documents

* Controllers
  * [Working with Content Controller](docs/controllers/content.md)
  * [Working with Stream Controller](docs/controllers/stream.md)

## License

The module is available as open source under the terms of the [Apache License, Version 2.0](https://opensource.org/licenses/Apache-2.0)